GCPlugin

Struct GCPlugin 

pub struct GCPlugin<T: GCPluginCallbackHandler> {
    plugin_instances: HashMap<String, GCPluginInstance<T>>,
    lib: PluginDLL,
}
GCPlugin holds the plugin instances for a particular plugin library.

Fields

plugin_instances: HashMap<String, GCPluginInstance<T>>lib: PluginDLL

Implementations



impl<T: GCPluginCallbackHandler> GCPlugin<T>

pub(crate) fn new(lib: PathBuf) -> Result<Self, GCPluginManagerError>

Creates a new plugin by loading it’s DLL using GCPluginDLL.

pub(crate) fn add_instance( &mut self, instance_name: &str, callback_handler: Box<T>, ) -> Result<GCPluginInstance<T>, GCPluginManagerError>

Adds a new instance to the plugin without starting it.

pub(crate) fn stop_instance( &self, instance_name: &str, ) -> Result<(), GCPluginManagerError>

pub(crate) fn start_instance( &mut self, config: GCPluginInstanceConfig<'_>, instance_name: &str, ) -> Result<GCPluginInstance<T>, GCPluginManagerError>

Starts the instance by initializing it with the given configuration and callback handler.

pub(crate) fn remove_instance( &mut self, instance_name: &str, ) -> Result<(), GCPluginManagerError>

This function will remove the instance from the plugin and shutdown the instance.

pub(crate) fn get_plugin_dll(&self) -> &PluginDLL

Returns the plugin DLL.

pub fn get_plugin_info(&self) -> GCPluginInfo

Returns the plugin info by calling gc_plugin_get_info

pub fn get_num_instances(&self) -> usize

Returns the number of instances for this plugin.

pub fn get_plugin_path(&self) -> &Path

Returns the path to the plugin DLL.

pub fn iter(&self) -> impl Iterator<Item = &GCPluginInstance<T>>

Returns an iterator over all instances for this plugin.

pub fn get_instance(&self, instance_name: &str) -> Option<&GCPluginInstance<T>>